#--------------------------------------------------------------------------------
# kugel_h1.py
#--------------------------------------------------------------------------------
# Eine Kugel rollt von links nach rechts durch das Bild.
# Das wird als "Film" durch aufeinanderfolgende Bilder angezeigt.
# Von der Kommandozeile werden ein float schrittweite (Abstand der Kugel von Bild zu Bild)
# und ein int anzeigedauer (Anzeigezeit jedes Bildes in ms) gelesen.
#--------------------------------------------------------------------------------

import sys, stddraw

schrittweite = float(sys.argv[1]) 
anzeigedauer = int(sys.argv[2])

# Die Leinwand hat x-Koordinaten 0..1 und y-Koordinaten 0..1.
# Der Startpunkt der Kugel  ist (0,0.5) -- d.h. in der Mitte am linken Rand der Leinwand.
# Die Kugel soll horizontal bis zum rechten Rand rollen.
# Der Punkt (x_pos,y_pos) ist die aktuelle Position der Kugel.
x_pos = 0.0    
y_pos = 0.5

# Die Kugel hat Radius 0.08 und ist rot.
RADIUS = 0.08  
stddraw.setPenColor(stddraw.RED)

# Die Bewegung entsteht, indem aufeinanderfolgende Bilder gezeigt werden,
# bei denen die Kugel jedesmal ein kleines Stück weiter nach rechts rollt.
# Das wird erreicht, indem schrittweite zu x_pos addiert wird,
# die Leinwand gelöscht und mit der Kugel an der neuen Position angezeigt wird.
# Der rechte Rand ist erreicht, wenn x_pos>=1.0 .
while x_pos<=1.0:
    # Bestimme die nächste Position der Kugel.
    x_pos = x_pos + schrittweite
    # Lösche die Leinwand, male die Kugel auf ihrer neuen Position
    # und zeige die (gelbe) Leinwand an.
    stddraw.clear(stddraw.YELLOW)
    stddraw.filledCircle(x_pos, y_pos, RADIUS)
    stddraw.show(anzeigedauer)

# Zeige das Bild noch 1 Sekunde an.
stddraw.show(1000)

#-------------------------------------------------------------------------------
# python3 kugel_h1.py 100 0.1
#
# python3 kugel_h1.py 25 0.005

