#--------------------------------------------------------------------------------
# kugel_h2.py
#--------------------------------------------------------------------------------
# Eine Kugel prallt zwischen dem linken und rechten Rand des Bildes hin und her.
# Das wird als "Film" durch aufeinanderfolgende Bilder angezeigt.
# Von der Kommandozeile wird ein float schrittweite (Änderung der x-Position der 
# Kugel pro Bild) und ein int anzeigedauer (Anzeigezeit jedes Bildes in ms) gelesen.
#--------------------------------------------------------------------------------

import sys, stddraw

schrittweite = float(sys.argv[1])
anzeigedauer = int(sys.argv[2]) 

# Die Leinwand hat x-Koordinaten 0..1 und y-Koordinaten 0..1.
# Der Startpunkt der Kugel  ist (0.1,0.5) -- d.h. in der Mitte am linken Rand der Leinwand.
# Die Kugel soll horizontal rollen.
# Der Punkt (x_pos,y_pos) ist die aktuelle Position der Kugel.
x_pos = 0.1   
y_pos = 0.5

# Die Kugel hat Radius 0.08 und ist rot.
RADIUS = 0.08  
stddraw.setPenColor(stddraw.RED)

# Die Bewegung entsteht, indem aufeinanderfolgende Bilder gezeigt werden,
# bei denen die Kugel jedesmal ein kleines Stück weiter nach rechts rollt.
# Das wird erreicht, indem schrittweite zu x_pos addiert wird,
# die Leinwand gelöscht und mit der Kugel an der neuen Position angezeigt wird.
# Wenn der rechte oder der linke Rand erreicht wird, läuft die Kugel in die umgekehrte Richtung.

while True:
    # Bestimme die nächste Position der Kugel.
    if x_pos<=0 or x_pos>=1: 
       schrittweite = -schrittweite
    x_pos = x_pos + schrittweite
    # Lösche die Leinwand, male die Kugel auf ihrer neuen Position
    # und zeige die (gelbe) Leinwand an.
    stddraw.clear(stddraw.YELLOW)
    stddraw.filledCircle(x_pos, y_pos, RADIUS)
    stddraw.show(anzeigedauer)

#-------------------------------------------------------------------------------
# python3 kugel_h2.py 100 0.1
#
# python3 kugel_h2.py 25 0.005

