#-----------------------------------------------------------------------------------------
# male_glatte_kurve_mit_achsen.py
#-----------------------------------------------------------------------------------------
# Lies xmin, xmax, ymin und ymax von der Kommandozeile.
# Lies Wertepaare x,y von standard input
# und male sie als mit Strichen verbundene Punkte auf eine Leinwand
# mit x-Achse xmin..xmax und y-Achse ymin..ymax. 
# Dabei wird die Linie geglättet, indem für jeden y-Wert der Durchschnitt seiner
# 9er-Nachbarschaft genommen wird.
#-----------------------------------------------------------------------------------------
import sys, stddraw
# Wir lesen zuerst alle Punkte von standard input.
# Wir schreiben alle x-Werte in ein Array x[], und alle y-Werte in ein Array y[].
# Dann ist (x[i],y[i]) jeweils ein Punkt.
xwerte = []
ywerte = []
for zeile in sys.stdin:
  punkt = str.split(zeile)
  xwerte += [ float(punkt[0]) ]
  ywerte += [ float(punkt[1]) ]

# Um die Leinwand vorzubereiten, 
# lesen wir von der Kommandozeile die Längen der x- und der y-Achse.
xmin = float(sys.argv[1])
xmax = float(sys.argv[2])
ymin = float(sys.argv[3])
ymax = float(sys.argv[4])
# Zum Malen der Achsen und deren Beschriftung brauchen wir an jeder Seite etwas Rand.
stddraw.setXscale(xmin-10, xmax+10)
stddraw.setYscale(ymin-2, ymax+2)
stddraw.setPenRadius(0.04)

# Male die x-Achse und die y-Achse des Koordinatensystems (in blau).
stddraw.setPenColor(stddraw.BLUE)
stddraw.line(xmin,ymin, xmax,ymin)
stddraw.line(xmin,ymin, xmin,ymax)

# Beschrifte die Achsen des Koordinatensystems.
if ymax-ymin>=10: d=int(ymax-ymin)//10 # bestimme den Abstand der kleinen Striche auf der y-Achse
else: d=1

for i in range(int(ymin), int(ymax+1), d):  # beschrifte die y-Achse
  stddraw.line(xmin-2,i, xmin+2,i)    # male einen kleinen waagerechten Strich über die y-Achse in Höhe i
  stddraw.text(xmin-5, i, str(i))     # schreibe i links neben die y-Achse in Höhe i

for i in range(int(xmin), int(xmax+1), int(xmax-xmin)//10): # beschrifte die x-Achse (Striche im 10er-Abstand)
  stddraw.line(i,ymin-0.2, i, ymin+0.2) # male einen kleinen senkrechten Strich an Stelle i der x-Achse
  stddraw.text(i, ymin-1, str(i))       # schreibe i etwas unter die x-Achse an Stelle i

# Die Linien zwischen aufeinanderfolgenden (x,y)-Paaren werden gemalt. 
stddraw.setPenColor(stddraw.BLACK)
stddraw.setPenRadius(0.14)
for i in range(4,len(xwerte)-5):
  stddraw.line( xwerte[i], sum(ywerte[i-4:i+5])/9, xwerte[i+1], sum(ywerte[i-3:i+6])/9 )

# Zeige das Bild an.
stddraw.show()

#-----------------------------------------------------------------------------------------
# python3 filter-jahr.py 15 < Jena-Wetterdaten.txt | python3 jahres_mittel.py  | \
#   python3 male_kurve_mit_achsen.py 1820 2020 -1 20  
#







